==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Effect/soxr/translations/soxr_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="31"/>
        <source>SoX Resampler Plugin</source>
        <translation>Suplemento SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Sobre o suplemento SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Suplemento Qmmp SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SoX Resampler Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Sample Rate (Hz):</source>
        <translation>Frequência (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="49"/>
        <source>Quality:</source>
        <translation>Qualidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Muito baixa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Média</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Muito alta</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Effect/soxr/translations/soxr_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="31"/>
        <source>SoX Resampler Plugin</source>
        <translation>Suplemento SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Sobre o suplemento SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Suplemento Qmmp SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Frequência (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation>Qualidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Muito baixa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Média</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Muito alta</translation>
    </message>
</context>
</TS>
